# This file is encoded in Shift_JIS.
die "This file is not encoded in Shift_JIS.\n" if '‚ ' ne "\x82\xA0";
die "This script is for perl only. You are using $^X.\n" if $^X =~ /jperl/i;

use strict;
use FindBin;
use lib "$FindBin::Bin/../lib";
use mb;
mb::set_script_encoding('sjis');
use vars qw(@test);

@test = (
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 1
---
'ƒ@'
END1
---
'ƒ@'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 2
'ƒA'
END1
'ƒA'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 3
'ƒB'
END1
'ƒB'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 4
'ƒC'
END1
'ƒC'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 5
'ƒD'
END1
'ƒD'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 6
'ƒE'
END1
'ƒE'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 7
'ƒF'
END1
'ƒF'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 8
'ƒG'
END1
'ƒG'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 9
'ƒH'
END1
'ƒH'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 10
'ƒI'
END1
'ƒI'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 11
'ƒJ'
END1
'ƒJ'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 12
'ƒK'
END1
'ƒK'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 13
'ƒL'
END1
'ƒL'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 14
'ƒM'
END1
'ƒM'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 15
'ƒN'
END1
'ƒN'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 16
'ƒO'
END1
'ƒO'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 17
'ƒP'
END1
'ƒP'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 18
'ƒQ'
END1
'ƒQ'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 19
'ƒR'
END1
'ƒR'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 20
'ƒS'
END1
'ƒS'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 21
'ƒT'
END1
'ƒT'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 22
'ƒU'
END1
'ƒU'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 23
'ƒV'
END1
'ƒV'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 24
'ƒW'
END1
'ƒW'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 25
'ƒX'
END1
'ƒX'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 26
'ƒY'
END1
'ƒY'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 27
'ƒZ'
END1
'ƒZ'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 28
'ƒ['
END1
'ƒ['
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 29
'ƒ\'
END1
'ƒ\\'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 30
'ƒ]'
END1
'ƒ]'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 31
'ƒ^'
END1
'ƒ^'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 32
'ƒ_'
END1
'ƒ_'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 33
'ƒ`'
END1
'ƒ`'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 34
'ƒa'
END1
'ƒa'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 35
'ƒb'
END1
'ƒb'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 36
'ƒc'
END1
'ƒc'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 37
'ƒd'
END1
'ƒd'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 38
'ƒe'
END1
'ƒe'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 39
'ƒf'
END1
'ƒf'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 40
'ƒg'
END1
'ƒg'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 41
'ƒh'
END1
'ƒh'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 42
'ƒi'
END1
'ƒi'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 43
'ƒj'
END1
'ƒj'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 44
'ƒk'
END1
'ƒk'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 45
'ƒl'
END1
'ƒl'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 46
'ƒm'
END1
'ƒm'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 47
'ƒn'
END1
'ƒn'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 48
'ƒo'
END1
'ƒo'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 49
'ƒp'
END1
'ƒp'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 50
'ƒq'
END1
'ƒq'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 51
'ƒr'
END1
'ƒr'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 52
'ƒs'
END1
'ƒs'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 53
'ƒt'
END1
'ƒt'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 54
'ƒu'
END1
'ƒu'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 55
'ƒv'
END1
'ƒv'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 56
'ƒw'
END1
'ƒw'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 57
'ƒx'
END1
'ƒx'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 58
'ƒy'
END1
'ƒy'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 59
'ƒz'
END1
'ƒz'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 60
'ƒ{'
END1
'ƒ{'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 61
'ƒ|'
END1
'ƒ|'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 62
'ƒ}'
END1
'ƒ}'
END2
    sub { $_=<<'END1'; mb::parse() eq <<'END2'; }, # test no 63
'ƒ~'
END1
'ƒ~'
END2
);

$|=1; print "1..",scalar(@test),"\n"; my $testno=1; sub ok { print $_[0]?'ok ':'not ok ',$testno++,$_[1]?" - $_[1]\n":"\n" } ok($_->()) for @test;

__END__
